<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\V1\Chemicals;

use App\Exceptions\ServerRunTimeException;
use App\Rhawn\Services\Chemsite\ChemsiteCompanyService;
use App\Services\Api\ChemicalsMsdsService;
use App\Services\Api\Chemsite\ChemsiteCustomerService;
use App\Services\Api\RhawnOrdersService;
use App\Services\CustomerService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

use OpenApi\Annotations\Post;
use OpenApi\Annotations\RequestBody;
use OpenApi\Annotations\MediaType;
use OpenApi\Annotations\Schema;
use OpenApi\Annotations\Property;
use OpenApi\Annotations\Response as AnnotationResponse;
use OpenApi\Annotations as OA;


class MsdsController extends Controller
{
    use Helpers;

    public function __construct(ChemicalsMsdsService $chemicalsMsdsService)
    {
       $this->chemicalsMsdsService= $chemicalsMsdsService;
    }

    public function getMsds(Request $request)
    {
        $companyCode = $request->get('company_code');
        $cusNumber = $request->get('cus_number');
        if(!$companyCode){
            return Response::ok('验证失败,参数缺少!');
        }

        $companyInfo = app(ChemsiteCompanyService::class)->getCompanyThroughCusCode($companyCode);
        if(!$companyInfo){
            throw new ServerRunTimeException('经销商不存在');
        }
        if($cusNumber){
            $customer = app(ChemsiteCustomerService::class)->getCustomerByNumber($cusNumber);
            if(!$customer){
                throw new ServerRunTimeException('客户不存在');
            }
        }
        if($customer['com_id'] != $companyInfo['com_id']){
            throw new ServerRunTimeException('不是该经销商的客户');
        }

        $platformCompanyInfo = app(CustomerService::class)->getPlatformCustomer(['cus_number' => $companyCode]);
        $this->chemicalsMsdsService->getMsds('270912-72-6', 'cn', $platformCompanyInfo);


        $customerCode = $request->get('customer_code');
        $companyCode = $request->get('company_code');
        $cusNumber = $request->get('cus_number');
        if(!$companyCode){
            return Response::ok('验证失败,参数缺少!');
        }
        if(!$customerCode){
            return Response::ok('客户编号不存在!');
        }
        $this->checkCustomerType($customerCode,$this->controllerType);

        $requestParams = $this->formatKeysfromArray($request->all(),'toUnderScore');
        $requestParams = array_merge($requestParams,['customer_code' => $customerCode]);
        try{
            $orderList = $this->rhawnOrdersService->getCustomerRhawnOrdersList($requestParams);
            if($orderList){
                $orderList = $this->formatKeysfromArray($orderList,'toCamelCase');
            }
            return Response::success($orderList,'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'获取订单列表失败');
        }
    }

}
